##  Disabling All Notifications for Your Organization
If needed, you can disable notifications for all your organization's workspaces. To do that, on the Account Level Settings tab, select the Disable all account notifications checkbox.
YesNo
Send
